@@ -228,7 +228,10 @@ static int elpa_double_value_to_string(char *name, double value, const char **st
         }
 
 /* The order here is important! Tunable options that are dependent on other
- * tunable options must appear later in the list than their prerequisites */
+ * tunable options must appear later in the list than their prerequisites.
+ * It is important that we only use underscores in setting names. Dashes
+ * must not be used, because setting environment variables like
+ * ELPA_FORCE_foo-bar would not work. */
 static const elpa_index_int_entry_t int_entries[] = {
         INT_PARAMETER_ENTRY("na", "Global matrix has size (na * na)", na_is_valid, PRINT_STRUCTURE),
         INT_PARAMETER_ENTRY("nev", "Number of eigenvectors to be computed, 0 <= nev <= na", nev_is_valid, PRINT_STRUCTURE),
@@ -275,6 +278,11 @@ static const elpa_index_int_entry_t int_entries[] = {
         INT_ENTRY("cannon_buffer_size", "Increasing the buffer size might make it faster, but costs memory", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY,  ELPA_AUTOTUNE_PART_NONE, \
                         cannon_buffer_size_cardinality, cannon_buffer_size_enumerate, cannon_buffer_size_is_valid, NULL, PRINT_YES),
         // tunables
+#if defined(WITH_NVIDIA_NCCL) || defined(WITH_AMD_RCCL)
+        BOOL_ENTRY("use_ccl", "Use NVIDIA's nccl or AMD's rccl communication libraries", 1, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, PRINT_YES), 
+#else
+        BOOL_ENTRY("use_ccl", "Use NVIDIA's nccl or AMD's rccl communication libraries", 0, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, PRINT_YES), 
+#endif
 	// 1. non-blocking MPI
         INT_ENTRY("nbc_row_global_gather", "Use non blocking collectives for rows in global_gather", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_SOLVE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
                         cardinality_bool, enumerate_identity, nbc_is_valid, NULL, PRINT_YES),
