@@ -99,8 +99,10 @@
 #undef  PRECISION_GER
 #undef  gpublas_PRECISION_GEMM
 #undef  gpublas_PRECISION_TRMM
+#undef  gpublas_PRECISION_SYRK_HERK
 #undef  gpublas_PRECISION_GEMV
 #undef  gpublas_PRECISION_SYMV
+#undef  gpublas_PRECISION_TRMV
 #undef  gpublas_PRECISION_COPY
 #undef  gpublas_PRECISION_TRSM
 #undef  gpublas_PRECISION_DOT
@@ -155,6 +157,23 @@
 #undef  GPU_GET_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION
 #undef  GPU_PUT_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION
 
+#undef GPU_DISTRIBUTE_GLOBAL_COLUMN_PRECISION
+#undef GPU_COPY_QMAT1_TO_QMAT2_PRECISION
+#undef GPU_UPDATE_D_PRECISION
+#undef GPU_COPY_D_TO_D_TMP_PRECISION
+
+#undef GPU_COPY_Q_SLICE_TO_QTMP1_PRECISION
+#undef GPU_ZERO_Q_PRECISION
+#undef GPU_COPY_QTMP1_TO_QTMP1_TMP_PRECISION
+#undef GPU_FILL_TMP_ARRAYS_PRECISION
+#undef GPU_COPY_QTMP1_SLICE_TO_Q_PRECISION
+#undef GPU_COPY_Q_SLICE_TO_QTMP2_PRECISION
+#undef GPU_FILL_EV_PRECISION
+#undef GPU_COPY_QTMP2_SLICE_TO_Q_PRECISION
+
+#undef  gpusolver_PRECISION_syevd 
+#undef GPU_CONSTRUCT_TRIDI_MATRIX_PRECISION
+#undef GPU_CHECK_MONOTONY_PRECISION
 #if 0
 /* General definitions needed in single and double case */
 /* the if 0 bracket is just to make the IBM Fortran compiler happy */
@@ -208,8 +227,10 @@
 #define  PRECISION_AXPY DAXPY
 #define  gpublas_PRECISION_GEMM gpublas_DGEMM
 #define  gpublas_PRECISION_TRMM gpublas_DTRMM
+#define  gpublas_PRECISION_SYRK_HERK gpublas_DSYRK
 #define  gpublas_PRECISION_GEMV gpublas_DGEMV
 #define  gpublas_PRECISION_SYMV gpublas_DSYMV
+#define  gpublas_PRECISION_TRMV gpublas_DTRMV
 #define  gpublas_PRECISION_COPY gpublas_DCOPY
 #define  gpublas_PRECISION_TRSM gpublas_DTRSM
 #define  gpublas_PRECISION_DOT  gpublas_DDOT
@@ -266,6 +287,24 @@
 #define GPU_GET_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_get_skewsymmetric_second_half_q_double
 #define GPU_PUT_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_put_skewsymmetric_second_half_q_double
 
+#define GPU_DISTRIBUTE_GLOBAL_COLUMN_PRECISION gpu_distribute_global_column_double
+#define GPU_COPY_QMAT1_TO_QMAT2_PRECISION gpu_copy_qmat1_to_qmat2_double
+#define GPU_UPDATE_D_PRECISION gpu_update_d_double
+#define GPU_COPY_D_TO_D_TMP_PRECISION gpu_copy_d_to_d_tmp_double
+
+#define GPU_COPY_Q_SLICE_TO_QTMP1_PRECISION gpu_copy_q_slice_to_qtmp1_double
+#define GPU_ZERO_Q_PRECISION gpu_zero_q_double
+#define GPU_COPY_QTMP1_TO_QTMP1_TMP_PRECISION gpu_copy_qtmp1_to_qtmp1_tmp_double
+#define GPU_FILL_TMP_ARRAYS_PRECISION gpu_fill_tmp_arrays_double
+#define GPU_COPY_QTMP1_SLICE_TO_Q_PRECISION gpu_copy_qtmp1_slice_to_q_double
+#define GPU_COPY_Q_SLICE_TO_QTMP2_PRECISION gpu_copy_q_slice_to_qtmp2_double
+#define GPU_FILL_EV_PRECISION gpu_fill_ev_double
+#define GPU_COPY_QTMP2_SLICE_TO_Q_PRECISION gpu_copy_qtmp2_slice_to_q_double
+
+#define  gpusolver_PRECISION_syevd gpusolver_dsyevd
+#define GPU_CONSTRUCT_TRIDI_MATRIX_PRECISION gpu_construct_tridi_matrix_double
+
+#define GPU_CHECK_MONOTONY_PRECISION gpu_check_monotony_double
 #endif /* DOUBLE_PRECISION */
 
 #ifdef SINGLE_PRECISION
@@ -315,8 +354,10 @@
 #define  PRECISION_AXPY SAXPY
 #define  gpublas_PRECISION_GEMM gpublas_SGEMM
 #define  gpublas_PRECISION_TRMM gpublas_STRMM
+#define  gpublas_PRECISION_SYRK_HERK gpublas_SSYRK
 #define  gpublas_PRECISION_GEMV gpublas_SGEMV
 #define  gpublas_PRECISION_SYMV gpublas_SSYMV
+#define  gpublas_PRECISION_TRMV gpublas_STRMV
 #define  gpublas_PRECISION_COPY gpublas_SCOPY
 #define  gpublas_PRECISION_TRSM gpublas_STRSM
 #define  gpublas_PRECISION_DOT  gpublas_SDOT
@@ -373,6 +414,24 @@
 #define GPU_GET_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_get_skewsymmetric_second_half_q_float
 #define GPU_PUT_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_put_skewsymmetric_second_half_q_float
 
+#define GPU_DISTRIBUTE_GLOBAL_COLUMN_PRECISION gpu_distribute_global_column_float
+#define GPU_COPY_QMAT1_TO_QMAT2_PRECISION gpu_copy_qmat1_to_qmat2_float
+#define GPU_UPDATE_D_PRECISION gpu_update_d_float
+#define GPU_COPY_D_TO_D_TMP_PRECISION gpu_copy_d_to_d_tmp_float
+
+#define GPU_COPY_Q_SLICE_TO_QTMP1_PRECISION gpu_copy_q_slice_to_qtmp1_float
+#define GPU_ZERO_Q_PRECISION gpu_zero_q_float
+#define GPU_COPY_QTMP1_TO_QTMP1_TMP_PRECISION gpu_copy_qtmp1_to_qtmp1_tmp_float
+#define GPU_FILL_TMP_ARRAYS_PRECISION gpu_fill_tmp_arrays_float
+#define GPU_COPY_QTMP1_SLICE_TO_Q_PRECISION gpu_copy_qtmp1_slice_to_q_float
+#define GPU_COPY_Q_SLICE_TO_QTMP2_PRECISION gpu_copy_q_slice_to_qtmp2_float
+#define GPU_FILL_EV_PRECISION gpu_fill_ev_float
+#define GPU_COPY_QTMP2_SLICE_TO_Q_PRECISION gpu_copy_qtmp2_slice_to_q_float
+
+#define  gpusolver_PRECISION_syevd gpusolver_ssyevd
+#define GPU_CONSTRUCT_TRIDI_MATRIX_PRECISION gpu_construct_tridi_matrix_float
+
+#define GPU_CHECK_MONOTONY_PRECISION gpu_check_monotony_float
 #endif /* SINGLE_PRECISION */
 
 #endif /* REALCASE */
@@ -435,8 +494,10 @@
 #undef  PRECISION_AXPY
 #undef  gpublas_PRECISION_GEMM
 #undef  gpublas_PRECISION_TRMM
+#undef  gpublas_PRECISION_SYRK_HERK
 #undef  gpublas_PRECISION_GEMV
 #undef  gpublas_PRECISION_SYMV
+#undef  gpublas_PRECISION_TRMV
 #undef  gpublas_PRECISION_COPY
 #undef  gpublas_PRECISION_TRSM
 #undef  gpublas_PRECISION_DCAL
@@ -552,8 +613,10 @@
 #define  PRECISION_AXPY ZAXPY
 #define  gpublas_PRECISION_GEMM gpublas_ZGEMM
 #define  gpublas_PRECISION_TRMM gpublas_ZTRMM
+#define  gpublas_PRECISION_SYRK_HERK gpublas_ZHERK
 #define  gpublas_PRECISION_GEMV gpublas_ZGEMV
 #define  gpublas_PRECISION_SYMV gpublas_ZSYMV
+#define  gpublas_PRECISION_TRMV gpublas_ZTRMV
 #define  gpublas_PRECISION_COPY gpublas_ZCOPY
 #define  gpublas_PRECISION_TRSM gpublas_ZTRSM
 #define  gpublas_PRECISION_DOT gpublas_ZDOT
@@ -660,8 +723,10 @@
 #define  PRECISION_GER CGER
 #define  gpublas_PRECISION_GEMM gpublas_CGEMM
 #define  gpublas_PRECISION_TRMM gpublas_CTRMM
+#define  gpublas_PRECISION_SYRK_HERK gpublas_CHERK
 #define  gpublas_PRECISION_GEMV gpublas_CGEMV
 #define  gpublas_PRECISION_SYMV gpublas_CSYMV
+#define  gpublas_PRECISION_TRMV gpublas_CTRMV
 #define  gpublas_PRECISION_COPY gpublas_CCOPY
 #define  gpublas_PRECISION_TRSM gpublas_CTRSM
 #define  gpublas_PRECISION_DOT  gpublas_CDOT
